# Revision Graph

A visually rich, interactive tool for viewing and exploring content revision histories in Drupal.

![Revision Graph Screenshot](https://www.drupal.org/files/project-images/Revision-Graph-3.x-02.png)
*Fig. A Revision Graph User Interface*

## Overview

Revision Graph transforms the standard Drupal revision history into an intuitive, visual graph that makes it easy to understand content changes over time. This is particularly valuable for:

- **Content editors** managing complex content with multiple contributors
- **Site administrators** tracking content changes and revision history
- **Editorial teams** visualizing workflow and content evolution

## Features for Content Creators

- **Interactive Visual Timeline**: See all content revisions displayed as an interactive graph
- **Revision Details**: Click on any revision to view commit details including author, date, and message
- **Contextual Information**: Visualize when changes were made with date markers
- **Branch Visualization**: Easily identify different content branches and how they merge
- **Tag Support**: Highlight important revisions with tags for quick reference
- **Accessibility Features**: Fully navigable by keyboard with screen reader support

## Features for Site Builders

- **Zero Configuration**: Works out of the box with any content type that has revisions enabled
- **Performance Optimized**: Efficiently handles content with large revision histories
- **Compatible with Core**: Works with standard Drupal revision functionality

## Installation

1. Download and install the module as you would normally install a contributed Drupal module.
   ```
   composer require drupal/revision_graph
   ```

2. Enable the module through the Drupal admin interface, or via Drush:
   ```
   drush en revision_graph
   ```

3. No additional configuration is required. The module is ready to use.

## Usage for Content Creators

### Viewing Revision History

1. Navigate to any content page that has revisions
2. Click on the "Revision Graph" tab (located next to standard "Revisions" tab)
3. The revision graph will display, showing the complete history of the content

### Understanding the Graph

- **Nodes (Circles)**: Each circle represents a single revision
- **Connecting Lines**: Show the relationship between revisions
- **Date Markers**: Horizontal lines indicating when revisions were made
- **Branch Labels**: Text at the top of each column showing branch names which is the language code.
- **Highlighted Current Revision**: The active revision is highlighted

### Working with Revisions

1. **View Revision Details**: Click on any revision circle to see detailed information
2. **Navigate Between Revisions**: Use keyboard arrow keys to move between revisions
3. **Access Revision Actions**: Each revision has a menu with options like:
   - View this revision
   - Revert to this revision
   - Compare with current revision

## Usage for Site Builders

### Enabling for Content Types

The module automatically adds the Revision Graph tab to any content type that has revisions enabled. To ensure it works with your content:

1. Go to Structure > Content types > [Your content type] > Edit
2. Expand the "Publishing options" section
3. Check "Create new revision" to enable revisions
4. Save the content type

### Customization Options

The graph appearance can be customized by:

1. **Theme Overrides**: Override the CSS classes in your theme to match your site's design
2. **Dark Mode Support**: The graph automatically detects and adapts to dark mode themes

## Troubleshooting

### The Revision Graph Tab Doesn't Appear

- Ensure that revisions are enabled for the content type
- Verify that the user has proper permissions to view revisions
- Clear the Drupal cache (`drush cr`)

### The Graph Doesn't Display Correctly

- Check for JavaScript errors in your browser's console
- Try clearing your browser cache
- Ensure your browser is up to date (the graph uses modern JavaScript features)

### Performance Issues with Large Revision Histories

- The graph is optimized for performance, but extremely large revision histories (hundreds of revisions) may cause slowdowns
- Consider pruning old revisions if they're no longer needed.

## Permissions

The module uses Drupal core's revision permissions:
- `view all revisions`: Required to see the Revision Graph tab
- No additional permissions are needed

## Support and Contribution

- For support requests, use the [issue queue](https://www.drupal.org/project/issues/revision_graph)
- For bug reports or feature suggestions, please provide detailed information including your Drupal version and steps to reproduce
- Contributions are welcome through the standard Drupal contribution process

## Maintainers

- Shibin Das - [D34dMan](https://www.drupal.org/u/d34dman)
